function [Corr, CorrMatrix, RoadPoints] = Calc_CorrMatrix(DataUBM_Interp2)
WindowSize = 5; % m The size of the moving window
WindowStep = 5;  % m stepsize of the moving window over distance
Context = {'HW', 'MT'};
%CorrMatrix: first column is the fuelconsumption per km averaged untill 4.0
%km, second column is the fuel consumption total.
%track. The other columns (2:end) are per road point and moving window
CorrMatrix{1} = [];  RoadPoints{1} = []; HW_corr = [];
CorrMatrix{2} = []; RoadPoints{2} = [];  MT_corr = [];

NamesIn  = {'FuelConsumption_Diff_per_km','GP','Speed','BrakePressure',...
    'LongAcc','va2','va','ECO','EngineRPM','MelmanMetrics'};
NamesOut = {'Fuel','GP','Speed','Brake',...
    'LongAcc','va2','va','ECO','EngineRPM','MelmanMetrics'}; 

% MelmanMetrics are currently: v + gp, v + a, v + a^2, v + brake, 
% v + a^2 + brake, v + 1/100*EngineRPM

% DataUBM_Interp2 consist of (1.rep number, (number of repetitions)
% 2. road_point_number, %(1:4001 for MT, 1:5600 for HW)
% 3. subject number, % Subject id
% 4. eco-driving number, % 1. Normal, 2. Eco
% 5. Vehicle number) % Mgane, Clio


for Cn = 1:2 % context number
    disp(['Cn = ' num2str(Cn) ' - ' Context{Cn}])
    DriveCounter = 1;
    for Vn = 1:2
        for cond = 1:2
            %cond = 2;
            for sub = 1:91
                IDrep = ~isnan(DataUBM_Interp2.(Context{Cn}).FuelConsumption_Cum_interp(:,100,sub,cond,Vn)); % Used to check the number of driven trials
                NrRep = sum(IDrep);
                
                if NrRep > 1
                    for rep = 1:NrRep
                        % Init per Context, Vn and cond
                        %Cnt_DATAUBM = 1;
                        StartPnt = 1;
                        EndPnt = WindowSize;
                        RoadPoint_cnt = 2;
                        ID_loo = IDrep; ID_loo(rep) = 0; %leave one out
                        
                        XLength = length(DataUBM_Interp2.(Context{Cn}).FuelConsumption_Cum_interp(rep,:,sub,cond,Vn))/1000; % km
                        for i = 1:length(NamesIn)
                            if ~strcmp(NamesIn{i},'MelmanMetrics')
                                TmpData.(NamesOut{i}) = DataUBM_Interp2.(Context{Cn}).(NamesIn{i})(rep,:,sub,cond,Vn);
                            end
                        end
                        
                        % leave one out total fuel consumption total
                        TotalFuel = sum(DataUBM_Interp2.(Context{Cn}).FuelConsumption_Cum(ID_loo,end,sub,cond,Vn));                       
                        %disp([num2str(rep) '/' num2str(NrRep)])
                        %disp(['Total Fuel: ' num2str(TotalFuel)])
                        % calc mean fuel consumption per drive *(store as first column in CorrMatrix)
                        FuelConsumptionPerKm = (TotalFuel/(sum(ID_loo)*XLength))./1000; % The leave one out mean fuel consumption
                        
                        %disp(['Sum km ' num2str(sum(ID_loo)*XLength)])
                        for i = 1:length(NamesIn)
                            if ~strcmp(NamesIn{i},'MelmanMetrics')
                                CorrMatrix{Cn}.(NamesOut{i})(DriveCounter,1)  = FuelConsumptionPerKm;
                            else
                                CorrMatrix{Cn}.v_gp(DriveCounter,1)  = FuelConsumptionPerKm; %km/hr & %
                                CorrMatrix{Cn}.v_a(DriveCounter,1)  = FuelConsumptionPerKm; %m/s & m/s^2
                                CorrMatrix{Cn}.v_a2(DriveCounter,1)  = FuelConsumptionPerKm; %m/s & m/s^2
                                CorrMatrix{Cn}.v_brake(DriveCounter,1)  = FuelConsumptionPerKm; %m/s & m/s^2
                                CorrMatrix{Cn}.v_a2_brake(DriveCounter,1)  = FuelConsumptionPerKm; %m/s & m/s^2 
                                CorrMatrix{Cn}.v_RPM(DriveCounter,1)  = FuelConsumptionPerKm; %m/s & m/s^2 
                                CorrMatrix{Cn}.v_10a2_RPM(DriveCounter,1)  = FuelConsumptionPerKm; %m/s & m/s^2 
                            end
                        end
                        
                        % Moving window stepsize and
                        while EndPnt < length(TmpData.(NamesOut{1}))
                            for i = 1:length(NamesIn)
                                if ~strcmp(NamesIn{i},'MelmanMetrics')
                                    CorrMatrix{Cn}.(NamesOut{i})(DriveCounter,RoadPoint_cnt) = (TmpData.(NamesOut{i})(EndPnt) + TmpData.(NamesOut{i})(StartPnt))/2;
                                end
                            end
                            
                            RoadPoints{Cn}(RoadPoint_cnt) = (EndPnt + StartPnt)/2; % in m
                            StartPnt = StartPnt + WindowStep;
                            EndPnt = EndPnt + WindowStep;
                            RoadPoint_cnt = RoadPoint_cnt + 1;
                        end
                        
                        % Calc Melman Metrics
                        CorrMatrix{Cn}.v_gp(DriveCounter,2:RoadPoint_cnt-1)       = [CorrMatrix{Cn}.Speed(DriveCounter,2:end)' + CorrMatrix{Cn}.GP(DriveCounter,2:end)']'; %km/hr & %
                        CorrMatrix{Cn}.v_a(DriveCounter,2:RoadPoint_cnt-1)        = [CorrMatrix{Cn}.Speed(DriveCounter,2:end)'./3.6 + CorrMatrix{Cn}.LongAcc(DriveCounter,2:end)']'; %m/s & m/s^2
                        CorrMatrix{Cn}.v_a2(DriveCounter,2:RoadPoint_cnt-1)       = [CorrMatrix{Cn}.Speed(DriveCounter,2:end)'./3.6 + (CorrMatrix{Cn}.LongAcc(DriveCounter,2:end)).^2']'; %m/s & m/s^2
                        CorrMatrix{Cn}.v_brake(DriveCounter,2:RoadPoint_cnt-1)    = [CorrMatrix{Cn}.Speed(DriveCounter,2:end)'./3.6 + CorrMatrix{Cn}.Brake(DriveCounter,2:end)']'; %m/s & m/s^2
                        CorrMatrix{Cn}.v_a2_brake(DriveCounter,2:RoadPoint_cnt-1) = [CorrMatrix{Cn}.Speed(DriveCounter,2:end)'./3.6 + (CorrMatrix{Cn}.LongAcc(DriveCounter,2:end)).^2' + CorrMatrix{Cn}.Brake(DriveCounter,2:end)']'; %m/s & m/s^2
                        CorrMatrix{Cn}.v_RPM(DriveCounter,2:RoadPoint_cnt-1)      = [CorrMatrix{Cn}.Speed(DriveCounter,2:end)' + 1/100*(CorrMatrix{Cn}.EngineRPM(DriveCounter,2:end))']'; %m/s & m/s^2
                        CorrMatrix{Cn}.v_10a2_RPM(DriveCounter,2:RoadPoint_cnt-1) = [CorrMatrix{Cn}.Speed(DriveCounter,2:end)' + 10*(CorrMatrix{Cn}.LongAcc(DriveCounter,2:end)).^2' + 1/100*(CorrMatrix{Cn}.EngineRPM(DriveCounter,2:end))']'; %m/s & m/s^2
                        
                        DriveCounter = DriveCounter + 1;
                    end
                end
            end
        end
    end
end

NameCorrFields = fields(CorrMatrix{Cn});

for i = 1:length(NameCorrFields)
    %Calc correlation
    Corr.(NameCorrFields{i}).HW = corr(CorrMatrix{1}.(NameCorrFields{i}),'type','spearman');
    Corr.(NameCorrFields{i}).HW = Corr.(NameCorrFields{i}).HW(1,:);
    Corr.(NameCorrFields{i}).MT = corr(CorrMatrix{2}.(NameCorrFields{i}),'type','spearman');
    Corr.(NameCorrFields{i}).MT = Corr.(NameCorrFields{i}).MT(1,:);
end
end