%% MultiVariateAnalyse

% This function calculates the multi variate analysis for all metrics
% explained in the paper

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% Calculate Table 4 in paper
% i.e, the Cohen's D per metric and spearman's correlation to
% fuel consumption
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
disp('Creating Figure 4')

TableTotal    = [];
RowCounter    = 1;
MetricCnt     = 1;
Data_Matrix = [];
PCACnt        = 1;

D_eco  = {[1,1,1;2,1,1],... % Compare HW Megane normal with HW Megane ECO
    [1,2,1;2,2,1],...
    [1,1,2;2,1,2],...
    [1,2,2;2,2,2]};

D_route   = {[1,1,1;1,1,2],... % Compare HW Megane normal with HW Megane ECO
    [1,2,1;1,2,2],...
    [2,1,1;2,1,2],...
    [2,2,1;2,2,2]};

D_vehicle = {[1,1,1;1,2,1],... % Compare HW Megane normal with HW Megane ECO
    [1,1,2;1,2,2],...
    [2,1,1;2,2,1],...
    [2,1,2;2,2,2]};
CohensD_Total = {D_eco D_route D_vehicle};

SignalNames = fields(Metrics_Averaged_Sub);
for SignalNum = 1:length(SignalNames)
    MetricNames = eval(sprintf('fields(Metrics_Averaged_Sub.%s);',SignalNames{SignalNum})); % Fieldnames are different per driver
    
    % Average for each metric
    for jj = 1:length(MetricNames)
        eval(sprintf('VariableNames{RowCounter,1} = ''%s.%s'';',SignalNames{SignalNum},MetricNames{jj}));
        VariableNamesPCA{PCACnt} = VariableNames{RowCounter};
        
        eval(sprintf('Y = Metrics_Averaged_Sub.%s.%s;',SignalNames{SignalNum},MetricNames{jj}));
        Y_m  = mean(Y,1,'omitnan');
        Y_SD = std(Y,1,'omitnan');
        for d_id = 1:length(CohensD_Total)
            for i = 1:4 %Index for which comparison need to be made
                %Y_m(1,cond,Vn,Cn);
                Yd_1  = Y_m(1,CohensD_Total{d_id}{i}(1,1),CohensD_Total{d_id}{i}(1,2),CohensD_Total{d_id}{i}(1,3));
                Yd_2  = Y_m(1,CohensD_Total{d_id}{i}(2,1),CohensD_Total{d_id}{i}(2,2),CohensD_Total{d_id}{i}(2,3));
                Yd_SD1 = Y_SD(1,CohensD_Total{d_id}{i}(1,1),CohensD_Total{d_id}{i}(1,2),CohensD_Total{d_id}{i}(1,3));
                Yd_SD2 = Y_SD(1,CohensD_Total{d_id}{i}(2,1),CohensD_Total{d_id}{i}(2,2),CohensD_Total{d_id}{i}(2,3));
                
                SD_pool_mean = sqrt(1/2*(Yd_SD1).^2 + ...
                    1/2*(Yd_SD2).^2);
                Y_CohenD(i) = (Yd_1 - Yd_2)/ SD_pool_mean;
            end
            CohenD_Average(d_id) = mean(Y_CohenD);
        end
        eval(sprintf('CohensD.%s.%s = CohenD_Average;',SignalNames{SignalNum},MetricNames{jj}));
        
        %% Correlation to Fuelconsumption
        Y_Fuel    = Metrics_Averaged_Sub.FuelConsumptionPerKm.mean;
        Y_Fuel_1d = reshape(Y_Fuel,[91*2*2*2,1]);
        Y_1d      = reshape(Y,[91*2*2*2,1]);
        % Remove Nan
        ID        = ~isnan(Y_Fuel_1d);
        Y_Fuel_1d = Y_Fuel_1d(ID);
        Y_1d      = Y_1d(ID);
        
        %Corr_PerSubject
        Corr_Subjects = corr(Y_1d,Y_Fuel_1d,'type','spearman');
        
        % Corr_PerDrive   =
        Y_Fuel_drives_1d = reshape(Metrics.FuelConsumptionPerKm.mean,[91*2*2*2*80,1]);
        eval(sprintf('Y_drives = Metrics.%s.%s;',SignalNames{SignalNum},MetricNames{jj}));
        Y_drives_1d = reshape(Y_drives,[91*2*2*2*80,1]);
        ID_NaN_Drives = isnan(Y_drives_1d);
        
        % Remove Nan
        ID        = ~isnan(Y_Fuel_drives_1d);
        Y_Fuel_drives_1d = Y_Fuel_drives_1d(ID);
        Y_drives_1d      = Y_drives_1d(ID);
        Corr_Drives = corr(Y_drives_1d,Y_Fuel_drives_1d,'type','spearman');
        
        %% put in one table
        % For PCA per drive!
        Data_Matrix(:,PCACnt) = Y_drives_1d;
        PCACnt = PCACnt + 1;
        
        % For Table 2 - averaged per participant!
        TableTotal(RowCounter,:) = [Y_m(1,1,1,1) Y_m(1,1,2,1) Y_m(1,1,1,2) ...
            Y_m(1,1,2,2) Y_m(1,2,1,1) Y_m(1,2,2,1) ...
            Y_m(1,2,1,2) Y_m(1,2,2,2) ...
            CohenD_Average ...
            Corr_Subjects Corr_Drives];
        RowCounter = RowCounter + 1;
        
        TableTotal(RowCounter,:) = [Y_SD(1,1,1,1) Y_SD(1,1,2,1) Y_SD(1,1,1,2) ...
            Y_SD(1,1,2,2) Y_SD(1,2,1,1) Y_SD(1,2,2,1) ...
            Y_SD(1,2,1,2) Y_SD(1,2,2,2) ...
            NaN NaN NaN ...
            NaN NaN];
        RowCounter = RowCounter + 1;
        
        CohenD_Average_total(MetricCnt,:) = CohenD_Average;
        MetricCnt = MetricCnt + 1;
    end
end

% Sort the matrix based on the ECO cohen's d score
[Y_sort, ID_sort] = sort(abs(CohenD_Average_total(:,1)),'descend');

% place nan at the end
ID_nan  = isnan(Y_sort);
Y_sort  = [Y_sort(~ID_nan); Y_sort(ID_nan)];
ID_sort = [ID_sort(~ID_nan); ID_sort(ID_nan)];

% Due to SD one row lower the rowID is the number of:
ID_sort = ID_sort + (ID_sort-1);

% Make sorted table
TableTotal_sorted    = [];
RowCounter = 1;
for pp = 1:length(Y_sort)
    TableTotal_Sorted_Short(pp,:) = TableTotal(ID_sort(pp),9:13);
    VariableNames_sorted_Short{pp,1} = VariableNames{ID_sort(pp)};
    
    TableTotal_sorted(RowCounter,:) = TableTotal(ID_sort(pp),:);
    VariableNames_sorted{RowCounter} = VariableNames{ID_sort(pp)};
    RowCounter = RowCounter + 1;
    
    TableTotal_sorted(RowCounter,:) = TableTotal(ID_sort(pp)+1,:);
    RowCounter = RowCounter + 1;
end

TableTotal_Short = TableTotal(1:2:end,9:13);
VariableNames_Short(:,1) = VariableNames(1:2:end)';


%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% DO PCA analysis
%%%%%%%%%%%%%%%%%%%%%%%%%%
Data_Matrix_norm =zscore(tiedrank(Data_Matrix)); % waarom nog extra tiedrank?
r=corr(Data_Matrix_norm);

eigr=sort(eig(r),'descend');
varexplained=100*(eigr./sum(eigr));

lding=CalcLoadings(r,3);
lding=rotatefactors(lding,'method','promax');
for i=1:size(lding,2)
    if mean(lding(:,i))<0
        lding(:,i)=-lding(:,i);
    end
end

pc_scores = zscore(Data_Matrix_norm)/lding';
[coefs, score] = pca(Data_Matrix_norm);

% Create PC_Out metrics with size (sub,ECO,Route,Vehicle,rep)
pc_scores_NaN = nan(length(ID_NaN_Drives),3);
cnt = 1;
for i = 1:length(ID_NaN_Drives)
    if ID_NaN_Drives(i) == 0
        pc_scores_NaN(i,:) = pc_scores(cnt,:);
        cnt = cnt +1;
    end
end

% ReShape
PC_Out.Component{1} = reshape(pc_scores_NaN(:,1),91,2,2,2,80);
PC_Out.Component{2} = reshape(pc_scores_NaN(:,2),91,2,2,2,80);
PC_Out.Component{3} = reshape(pc_scores_NaN(:,3),91,2,2,2,80);

%%%%%%%%%%%%%%%%%%%%%%%%%%
% Cohen's D for the Principle components
%%%%%%%%%%%%%%%%%%%%%%%%%%%
for PC_ID = 1:3
    % Average the rep per driver matrix size after -> 91*2*2*2
    Y = mean(PC_Out.Component{PC_ID},5,'omitnan');
    Y_m  = mean(Y,1,'omitnan');
    Y_SD = std(Y,1,'omitnan');
    for d_id = 1:length(CohensD_Total)
        for i = 1:4 %Index for which comparison need to be made
            %Y_m(1,cond,Vn,Cn);
            Yd_1  = Y_m(1,CohensD_Total{d_id}{i}(1,1),CohensD_Total{d_id}{i}(1,2),CohensD_Total{d_id}{i}(1,3));
            Yd_2  = Y_m(1,CohensD_Total{d_id}{i}(2,1),CohensD_Total{d_id}{i}(2,2),CohensD_Total{d_id}{i}(2,3));
            Yd_SD1 = Y_SD(1,CohensD_Total{d_id}{i}(1,1),CohensD_Total{d_id}{i}(1,2),CohensD_Total{d_id}{i}(1,3));
            Yd_SD2 = Y_SD(1,CohensD_Total{d_id}{i}(2,1),CohensD_Total{d_id}{i}(2,2),CohensD_Total{d_id}{i}(2,3));
            
            SD_pool_mean = sqrt(1/2*(Yd_SD1).^2 + ...
                1/2*(Yd_SD2).^2);
            Y_CohenD(i) = (Yd_1 - Yd_2)/ SD_pool_mean;
        end
        CohenD_PC_Out(d_id) = mean(Y_CohenD);
    end
    CohenD_PC_Out_total(PC_ID,:) = CohenD_PC_Out;
end

%% Make Table
% Extended Table 4 in paper
T1 = cell2table([VariableNames_sorted {[]}]');
T2 = array2table(TableTotal_sorted);
Table4_inPaper = [T1 T2];
%Table4_inPaper.Properties.VariableNames = {'Driving Measures' ...
%    'Cohen''s d Eco adherence' 'Cohen''s d Route type' ...
%    'Cohen''s d Vehicle Type' 'Spearman''s correlation to fuel consumption over subjects' ...
%    'Spearman''s correlation to fuel consumption over all drives'}


%% Plot figures PCA 2d  - without color
% Figure 4
% axis equal and axis square needs to be manually done later (bug in
% matlab)

figure(); hold on;
subplot(1,3,1); hold on
for sub = 1:91
    for Cond = 1:2
        for Vn = 1:2
            for Cn = 1:2
                p_a{Cn} = scatter(PC_Out.Component{1}(sub,Cond,Vn,Cn,:), ...
                    PC_Out.Component{2}(sub,Cond,Vn,Cn,:),3,...
                    Exp.color{Cn},'filled');
            end
        end
    end
end
xlabel('PC 1 - Route'); ylabel('PC 2 - Eco');
legend([p_a{1} p_a{2}],{'Highway','Mountain'})
xlim([-2 2]); %ylim([-2.5 2.5]);
axis equal
axis square

subplot(1,3,2); hold on
for sub = 1:91
    for Cond = 1:2
        for Vn = 1:2
            for Cn = 1:2
                p_a{Cond} = scatter(PC_Out.Component{1}(sub,Cond,Vn,Cn,:), ...
                    PC_Out.Component{2}(sub,Cond,Vn,Cn,:),3,...
                    Exp.color{Cond},'filled');
            end
        end
    end
end
xlabel('PC 1 - Route'); ylabel('PC 2 - Eco');
legend([p_a{1} p_a{2}],{'Normal','Eco'})
xlim([-2 2]); %ylim([-2.5 2.5]);
axis equal
axis square
fig=gcf;set(findall(fig,'-property','FontName'),'FontName','Arial','Fontsize',12)

subplot(1,3,3); hold on
for sub = 1:91
    for Cond = 1:2
        for Vn = 1:2
            for Cn = 1:2
                p_a{Vn} = scatter(PC_Out.Component{1}(sub,Cond,Vn,Cn,:), ...
                    PC_Out.Component{3}(sub,Cond,Vn,Cn,:),3,...
                    Exp.color{Vn},'filled');
            end
        end
    end
end
xlabel('PC 1 - Route'); ylabel('PC 3 - Vehicle');
legend([p_a{1} p_a{2}],{'Mgane','Clio'})
xlim([-2 2]);% ylim([-2.5 2.5]);
axis equal
axis square
fig=gcf;set(findall(fig,'-property','FontName'),'FontName','Arial','Fontsize',12)
% End Calc Cohen's D and Metrics