% Function to calculate the Situated dependent analysis used in the paper

%% Calc fuel consumption correlation as a moving 'correlation' filter
% % Again Highway is Cn = 1, Mountain is Cn = 2;
disp('Calculating situation dependent fuel correlations, this takes < 10 min...')
[Corr, CorrMatrix, RoadPoints] = Calc_CorrMatrix(DataUBM_Interp2);

%% Figure 5 & 6 in Paper - Seperated plotted - HW & MT
disp('Creating Figure 5-7')
LineWidth = 2;
NumRows = 7;
NumColumn = 1;
ylabelAngle = 0;
MKSize = 9;

Context = {'HW' 'MT'};
RGB_Normal = [0 0 0];
RGB_ECO = [0 1 0];
alpha = 0.3;
Marg_Gap = [0.02 0.05];
MargHeigth = [0.07 0.02];
MargWidth = [0.130 0.1];

    [~, Id_Speed_min] = min(Corr.Speed.MT(2:end));
    [~, Id_Speed_max] = max(Corr.Speed.MT(2:end));
    [~, Id_GP_min] = min(Corr.GP.MT(2:end));
    [~, Id_GP_max] = max(Corr.GP.MT(2:end));
    [~, Id_va2_min] = min(Corr.va2.MT(2:end));
    [~, Id_va2_max] = max(Corr.va2.MT(2:end));
    [~, Id_Fuel_min] = min(Corr.Fuel.MT(2:end));
    [~, Id_Fuel_max] = max(Corr.Fuel.MT(2:end));

for i = 1:2
    Y1 = DataUBM_Interp.(Context{i}).Vehicle(1);
    Y2 = DataUBM_Interp.(Context{i}).Vehicle(2);

    figure();
    % Instantaneous curvature HW
    subtightplot(NumRows,NumColumn,1,Marg_Gap, MargHeigth, MargWidth); hold on;
    Ycomb = mean([Y1.cond(1).CurvatureInstant; Y2.cond(1).CurvatureInstant], 'omitnan');
    plot(Ycomb,'k','linewidth',LineWidth);    
    ylabel({'Instant', 'curvature', '(deg/m)'},'rotation',0,'VerticalAlignment','middle','HorizontalAlignment','center','Position',[-419,0,-1])
    
    if i == 1 
        xlim([0 4000]); xticks(0:500:4000); title('Highway','Position',[2000,0.088,1.42e-14])
    else 
        xlim([0 5600]); xticks(0:500:5500); ylim([-0.75 0.6]); title('Mountain','Position',[2800,0.46,0])
    end
    ylim([-0.8 0.6])
    set(gca,'XTicklabel',{[]}); grid on
        
    % Altitude on the right side plotted
    yyaxis right
    Ycomb = median([Y1.cond(1).GPS_Altitude; Y2.cond(1).GPS_Altitude], 'omitnan');
    plot(Ycomb,'--r','linewidth',LineWidth);    
    ylabel({'Altitude', '(m)'},'rotation',0,'VerticalAlignment','middle','HorizontalAlignment','center','Color','r')
    ax = gca;
    ax.YAxis(2).Color = 'r';  
    ylim([40 130])
    yticks([40 80 120])
    
    % Speed HW
    subtightplot(NumRows,NumColumn,2,Marg_Gap, MargHeigth, MargWidth); hold on;
    p1 = stdshade([Y1.cond(1).Speed; Y2.cond(1).Speed],alpha,RGB_Normal);
    p2 = stdshade([Y1.cond(2).Speed; Y2.cond(2).Speed],alpha,RGB_ECO);
    ylabel({'Speed', '(km/hr)'},'rotation',0,'VerticalAlignment','middle','HorizontalAlignment','center','Position',[-375,105,-1])
    if i == 1
        xlim([0 4000])
        xticks(0:500:4000)
        ylim([50 150]); yticks([60 100 150])
    else
        xlim([0 5600])
        xticks(0:500:5500)
    end
    set(gca,'XTicklabel',{[]});
    ax = gca; ax.XGrid = 'on'; ax.YGrid = 'on';
    legend([p1 p2],{'Normal','ECO'}','Orientation','horizontal','Location','north')
    
    % Throttle & Brake together in one subplot
    subtightplot(NumRows,NumColumn,3,Marg_Gap, MargHeigth, MargWidth); hold on;
    stdshade([Y1.cond(1).GP; Y2.cond(1).GP],alpha,RGB_Normal);
    stdshade([Y1.cond(2).GP; Y2.cond(2).GP],alpha,RGB_ECO);
    ylabel({'Throttle', '(%)'},'rotation',0,'VerticalAlignment','middle','HorizontalAlignment','center','Position',[-375,55,-1])
    ylim([-100 100]);
    if i == 1
        xlim([0 4000]); xticks(0:500:4000)
    else
        xlim([0 5600]); xticks(0:500:5500)
    end
    set(gca,'XTicklabel',{[]});
    yticks(-100:50:100)
    set(gca,'YTicklabel',{'' '' 0 50 100});

    ax = gca; ax.XGrid = 'on'; ax.YGrid = 'on';
    
    % Brake
    yyaxis right
    stdshade([Y1.cond(1).BrakePressure; Y2.cond(1).BrakePressure],alpha,RGB_Normal);
    stdshade([Y1.cond(2).BrakePressure; Y2.cond(2).BrakePressure],alpha,RGB_ECO);
    
    yyaxis right
    ylabel({'Brake', 'pressure', '(bar)'},'rotation',0,'VerticalAlignment','middle','HorizontalAlignment','center') % 'Position',[-361,13,-1]
    set(gca,'ydir','reverse')
    
    if i == 1
        xlim([0 4000])
        xticks(0:500:4000)
    else
        xlim([0 5600])
        xticks(0:500:5500)
    end
    ylim([-40 40])
    yticks(-40:20:40)
    set(gca,'YTicklabel',{'' '' 0 20 40});
    set(gca,'XTicklabel',{[]});
    set(gca,'ycolor','r')
    ax = gca; ax.XGrid = 'on'; ax.YGrid = 'on';
        
    % Fuel consumption
    subtightplot(NumRows,NumColumn,4,Marg_Gap, MargHeigth, MargWidth); hold on;
    stdshade([Y1.cond(1).FuelConsumption_Diff_per_km; Y2.cond(1).FuelConsumption_Diff_per_km]./1000,alpha,RGB_Normal);
    stdshade([Y1.cond(2).FuelConsumption_Diff_per_km; Y2.cond(2).FuelConsumption_Diff_per_km]./1000,alpha,RGB_ECO);
    ylabel({'Fuel','consumption','(cm^3/km)'},'rotation',0,'VerticalAlignment','middle','HorizontalAlignment','center','Position',[-344,2.3,-1])
    
    if i == 1
        xlim([0 4000])
        xticks(0:500:4000)
    else
        xlim([0 5600])
        xticks(0:500:5500)
        ylim([0 300]); yticks([0 300]);
    end 
    set(gca,'XTicklabel',{[]});
    ax = gca; ax.XGrid = 'on'; ax.YGrid = 'on';
    
    % Spearman correlation HW & MT - Speed Throttle
    subtightplot(NumRows,NumColumn,[5:7],Marg_Gap, MargHeigth, MargWidth); hold on;
    plot(RoadPoints{i}(2:5:end),Corr.Speed.(Context{i})(2:5:end),'color',Exp.color{1},'linewidth',LineWidth,'LineStyle','-')
    plot(RoadPoints{i}(2:5:end),Corr.Fuel.(Context{i})(2:5:end),'color',Exp.color{3},'linewidth',LineWidth,'LineStyle','-')
    plot(RoadPoints{i}(2:5:end),Corr.GP.(Context{i})(2:5:end),'color',Exp.color{2},'linewidth',LineWidth,'LineStyle','-')
    if i == 2
        plot(RoadPoints{2}(Id_Speed_min+1),Corr.Speed.(Context{i})(Id_Speed_min+1),'ko','MarkerSize', MKSize,'MarkerFaceColor',Exp.color{1});   
        plot(RoadPoints{2}(Id_Speed_max+1),Corr.Speed.(Context{i})(Id_Speed_max+1),'k^','MarkerSize', MKSize,'MarkerFaceColor',Exp.color{1});  
        plot(RoadPoints{2}(Id_GP_min+1),Corr.GP.(Context{i})(Id_GP_min+1),'ko','MarkerSize', MKSize,'MarkerFaceColor',Exp.color{2});  
        plot(RoadPoints{2}(Id_GP_max+1),Corr.GP.(Context{i})(Id_GP_max+1),'k^','MarkerSize', MKSize,'MarkerFaceColor',Exp.color{2});  
        plot(RoadPoints{2}(Id_Fuel_min+1),Corr.Fuel.(Context{i})(Id_Fuel_min+1),'ko','MarkerSize', MKSize,'MarkerFaceColor',Exp.color{3});  
        plot(RoadPoints{2}(Id_Fuel_max+1),Corr.Fuel.(Context{i})(Id_Fuel_max+1),'k^','MarkerSize', MKSize,'MarkerFaceColor',Exp.color{3});  
    end
    legend({'Speed','Fuel consumption','Throttle'},'Orientation','horizontal','Location','north') %'Throttle'
    ylabel({'Cross','correlation', '(\rho)'},'rotation',0,'VerticalAlignment','middle','HorizontalAlignment','center','Position',[-382,0.5,-1])
    
    if i == 1
        xlim([0 4000])
        xticks(0:500:4000)
        ylim([-0.3 1.2])
    else
        xlim([0 5600])
        xticks(0:500:5500)
        ylim([-0.55 1.2])
    end 
        
    % Spearman correlation HW & MT - Long Acc - Fuel consumption
    ax = gca; ax.XGrid = 'on'; ax.YGrid = 'on';
    xlabel('Distance (m)')
    fig=gcf;set(findall(fig,'-property','FontName'),'FontName','Arial','Fontsize',11)
    a = get(gca,'XTickLabel');
end

%% Correlation plot with max and min rho
DATANames = {{'Speed','(km/hr)'},{'GP','(%)'},{'Fuel','consumption (cm^3/km)'}}; %,{'Brake','(bar)'},{'LongAcc','(m/s^2)'},{'Fuel','consumption (cm^3/s)'}};
PlotNames = {'Speed (km/hr)','Throttle (%)','Fuel consumption  (cm^3/km)'}; %,'Instant brake pressure (bar)','Instant long acceleration (m/s^2)','Instant fuel consumption'};
x = linspace(-100,2.5e5);

figure();
subplot_counter = 1;
for i = 1:length(DATANames)
    Y = CorrMatrix{2}.(DATANames{i}{1});
    
    if strcmp('Fuel',DATANames{i}{1}); Y(:,2:end) = Y(:,2:end)./1000; end
     [Y_min, Id_min] = min(Corr.(DATANames{i}{1}).MT(2:end));
     [Y_max, Id_max] = max(Corr.(DATANames{i}{1}).MT(2:end));
    
    % max
    subplot(length(DATANames),2,subplot_counter); hold on
    CorrPL = corr(Y(:,Id_max+1),Y(:,1),'type','Spearman');   
    scatter(Y(:,Id_max+1),Y(:,1),6,Exp.color{i},'filled');
    %[~,a,b] = regression(Y(:,Id_max+1)',Y(:,1)');
    %plot(x,(a.*x+b),'--r','LineWidth',2);
    xl = xlim;
    xlim(xl)
    
    text(0.6,0.15,['\rho = ' num2str(round(CorrPL,2))],'Units','normalized')
    xlabel(PlotNames{i})
    ylabel({'Overall','mean fuel', 'consumption','(cm^3/km)'});
    if i == 1; title('Max \rho');  end
    subplot_counter = subplot_counter  + 1;
    ylim([30 90])
        
    
    % min
    subplot(length(DATANames),2,subplot_counter); hold on
    CorrPL = corr(Y(:,Id_min+1),Y(:,1),'type','Spearman');
    scatter(Y(:,Id_min+1),Y(:,1),6,Exp.color{i},'filled');
    %[r,a,b] = regression(Y(:,Id_min+1)',Y(:,1)');
    %plot(x,a.*x+b,'--r','LineWidth',2);
    xl = xlim;
    xlim(xl)
        
    text(0.6,0.15,['\rho = ' num2str(round(CorrPL,2))],'Units','normalized')
    xlabel(PlotNames{i})
    if i == 1; title('Min \rho'); end
    ylim([30 90])
    subplot_counter = subplot_counter  + 1;
end

subplot(3,2,4); xlim([0 50]);
subplot(3,2,6); xlim([0 250]);
fig=gcf;set(findall(fig,'-property','FontName'),'FontName','Arial','Fontsize',12)