function plt_error_bars( DATA,  x_label, y_label, tick_labels,...
    BoxOrCI,plt_individual_lines)
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%% Error bars file created by Timo Melman %%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% This function creates an error bar plot input file 'Data'.
% - The columns are the conditions that need to be plotted in the matrix.
% - The rows are the participants
% - In case of repetitions this is done by a cell structure: e.g., Data{2}
%    But need to have the same number of conditions.
% In case of repetitions.

%% Init
% Width of the mean lines
width = 0.2;

rep_dist = 0.3;% (Distance between the repetitions)

% we're plotting the conditions on 1, 2, 3, etc. on the x-axis
% the clusters are spaced around the middle condition
marker = ['*','o','s','d','<','^','>','v'];
[color,color_l] = specify_colors();

if iscell(DATA)
    nr_rep = length(DATA);
    nr_cond = length(DATA{1}(1,:)); % Same nr-of conditions between rep!
else
    nr_rep = 1;
    nr_cond = length(DATA(1,:));
end

if nr_rep == 1
    for cond = 1:nr_cond % length(DATA(1,:)) = Number of conditions
        %disp(['analysing conditions']);
        means(cond,1)=mean(DATA(:,cond),'omitnan');
        [h, sig, cl] = ttest(DATA(:,cond), means(cond));
        CL(cond,1)=cl(2)-means(cond);
    end
else % For repetitions
    for rep = 1:nr_rep
        for cond = 1:nr_cond % length(DATA(1,:)) = Number of conditions
            %disp(['analysing conditions']);
            means{rep}(cond,1)=mean(DATA{rep}(:,cond),'omitnan');
            [h, sig, cl] = ttest(DATA{rep}(:,cond), means{rep}(cond));
            CL{rep}(cond,1)=cl(2)-means{rep}(cond);
        end
    end
end

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%% Plot error bars %%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% Plot Error bars
% open the figure
i=1; % counter for error bar position
%fig_handle = figure(); hold on;
if nr_rep == 1
    for cond=1:nr_cond
        xsmall{cond} = i + rand(length(DATA(:,cond)),1).*0.16 - 0.08;
        % To plot the data in the plot
        plot(xsmall{cond},DATA(:,cond),'*','color',color_l{cond})
        
        i=i+1;
    end
    
    % Plot the individual lines
    if plt_individual_lines
        for cond = 1:nr_cond-1
            plot([xsmall{cond} xsmall{cond+1}]', [DATA(:,cond) DATA(:,cond+1)]','-','color',[0.9 0.9 0.9])
        end
    end
else
    for rep = 1:nr_rep
        for cond = 1:nr_cond
            % x position of next condition (Distance between last rep en
            % next condition is fixed
            X_base{rep}{cond} = cond + nr_rep*rep_dist + rep_dist*(rep-1);
            
            % create random off-set around the base
            xsmall{rep}{cond} = X_base{rep}{cond} + rand(length(DATA{rep}(:,cond)),1).*0.16 - 0.08;
            % To plot the data in the plot
            h1{rep} = plot(xsmall{rep}{cond},DATA{rep}(:,cond),marker(rep),'color',color_l{cond},'MarkerFaceColor',color_l{cond});
        end
        
        % Plot the individual lines
        if plt_individual_lines
            for cond = 1:nr_cond-1
                plot([xsmall{rep}{cond} xsmall{rep}{cond+1}]', [DATA{rep}(:,cond) DATA{rep}(:,cond+1)]','-','color',[0.9 0.9 0.9])
            end
        end
    end
end

%% plot mean lines and the CI/boxplot
Ymin = [];
Ymax = [];
if nr_rep == 1
    i=1; % counter for error bar position
    for cond=1:nr_cond
        % Plot Confidence interval
        if (strcmp(BoxOrCI,'CI') )
            %errorbar(i,means(cond,clust),CL(cond,clust),['k',marker(clust)],'LineWidth',1.5); hold on;
            % draw the polygons in CW direction, starting upper left corner
            x_pos = [i-width/2 i+width/2 i+width/2 i-width/2];
            y_max = means(cond)+CL(cond);
            y_min = means(cond)-CL(cond);
            y_pos = [y_max y_max y_min y_min];
            plot((i)*[1,1],[y_min, y_max],'color',color{cond});
            plot([x_pos(1) x_pos(2)],y_min*[1,1],'color',color{cond});
            plot([x_pos(1) x_pos(2)],y_max*[1,1],'color',color{cond});
            
            % plot the mean line
            x=[i-width/2*1.5 i+width/2*1.5];
            y=[means(cond) means(cond)];
            %plot(x,y,'k','LineWidth',2+width); %old
            hline{cond} = plot(x,y,'k','LineWidth',2+width/2, 'color',color{cond});
        end
        
        % Plot boxplot
        if (strcmp(BoxOrCI,'BOX') )
            boxplot(DATA(:,cond),'Positions',cond,'ExtremeMode','compress',...
                'BoxStyle','filled','Colors',color{cond},'Widths',width)
        end
        i=i+1;
    end
    set(gca,'xtick',[1:nr_cond]);
    set(gca,'XTickLabel',tick_labels,'FontSize',14);
    xlabel(x_label,'FontSize',16);
    ylabel(y_label,'FontSize',16);
    
    %grid on;
    
    % fix the axis limits
    xlim([0.5 nr_cond+0.5]);
    ylimits =[min(min(DATA)) max(max(DATA))];
    bound = diff(ylimits)*0.05;
    ylim([ylimits(1)-bound ylimits(2)+bound]);
    
else % If there are repetitions!
    for rep = 1:nr_rep
        Ymin(rep) = min(min(DATA{rep}));
        Ymax(rep) = max(max(DATA{rep}));
        for cond=1:nr_cond
            % Plot Confidence interval
            if (strcmp(BoxOrCI,'CI') )
                %errorbar(i,means(cond,clust),CL(cond,clust),['k',marker(clust)],'LineWidth',1.5); hold on;
                % draw the polygons in CW direction, starting upper left corner
                i = X_base{rep}{cond};
                x_pos = [i-width/2 i+width/2 i+width/2 i-width/2];
                y_max = means{rep}(cond)+CL{rep}(cond);
                y_min = means{rep}(cond)-CL{rep}(cond);
                y_pos = [y_max y_max y_min y_min];
                plot((i)*[1,1],[y_min, y_max],'color',color{cond});
                plot([x_pos(1) x_pos(2)],y_min*[1,1],'color',color{cond});
                plot([x_pos(1) x_pos(2)],y_max*[1,1],'color',color{cond});
                
                % plot the mean line
                x=[i-width/2*1.5 i+width/2*1.5];
                y=[means{rep}(cond) means{rep}(cond)];
                %plot(x,y,'k','LineWidth',2+width); %old
                hline{cond} = plot(x,y,'k','LineWidth',2+width/2, 'color',color{cond});
            end
            
            % Plot boxplot
            if (strcmp(BoxOrCI,'BOX') )
                boxplot(DATA{rep}(:,cond),'Positions',cond,'ExtremeMode','compress',...
                    'BoxStyle','filled','Colors',color{cond},'Widths',width)
            end
            i=i+1;
        end
    end
    
    legend([h1{1} h1{2}],tick_labels{2},'Orientation','horizontal','Location','northoutside')
    
    set(gca,'xtick',[X_base{1}{:}]);
    set(gca,'XTickLabel',tick_labels{1},'FontSize',14);
    %xlabel(x_label,'FontSize',16);
    ylabel(y_label,'FontSize',16);
    xtickangle(45)
    
    % fix the axis limits
    xlim([X_base{1}{1}-0.5 X_base{2}{end}+0.5]);
    ylimits = [min(Ymin) max(Ymax)];
    bound = diff(ylimits)*0.05;
    ylim([ylimits(1)-bound ylimits(2)+bound]);
end
end
